#Libraries####
library(lme4)
library(glmmML)
library(pscl)
library(AER)
library(MASS)
library(RVAideMemoire)
library(ggplot2)
library(predictmeans)
library(effsize)
library(effects)
library(arm)
library(performance)
library(simr)
library(matrixStats)


opt.expon.mod <- function(model, expon=seq(4/100, 4, length=100)) {
  # Function that establishes to which exponent (power) a variable 
  # should be raised to maximise the probability of the supplied
  # model's residuals testing as being normally distributed using 
  # the Shapiro-Wilks test.
  #
  # The function takes two arguments: the base model and the
  # range of exponents to be tested. This range is set by default
  # to 100 values between 0 (but not including 0) and 4.
  #
  # Author: Emile van Lieshout
  # Date: 1/8/2013
  
  
  # Could use the commented-out code below to test whether specific
  # exponents < 1 equivalent to even roots are inappropriate if the
  # response contains negative numbers.
  #	form <- formula(model)
  #	dep <- as.character(form[2])
  #	rest <- as.character(c(form[c(1,3)]))
  
  start <- proc.time()
  pvals <- numeric(length(expon))
  opt_expon <- 0
  resid.best <- NULL
  
  for(i in 1:length(expon)) {
    form.upd <- as.formula(paste(".^", expon[i], " ~ .", sep=''))
    model.upd <- update(model, form.upd)
    
    pvals[i] <- shapiro.test(residuals(model.upd))$p.value
    
    if(pvals[i] >= max(pvals)) {
      opt_expon <- expon[i]
      resid.best <- residuals(model.upd)
    }
  }
  
  cat('Maximum observed Shapiro-Wilks p =', max(pvals), 'at exponent', opt_expon, '\n')
  
  layout(matrix(1:2, ncol=1))
  plot(expon, pvals, 
       type='l', 
       xlab="Dependent variable exponent used", 
       ylab="Observed Shapiro-Wilk test p")
  hist(resid.best)
  layout(1)
  
  cat("Calculated in", (proc.time() - start)[3], "seconds\n")
  
}

##################################################################
####################AOE TRIALS####################################
##################################################################

aoedata=read.csv("Simulated Battles.csv")
names(aoedata)

###Outcome####
aoebinom1=glm(outcome2~Treatment*Red.No,data=aoedata,
              family=binomial)
Anova(aoebinom1)
#Remove interaction
aoebinom2=glm(outcome2~Treatment+Red.No,data=aoedata,
              family=binomial)
Anova(aoebinom2)

#McFadden's R2
aoenullmod=glm(outcome2~1,family="binomial",data=aoedata)
aoeR2=1-logLik(aoebinom2)/logLik(aoenullmod)
aoeR2
#0.84

#Plot
aoebinomplot=glm(outcome2~treatment*Red.No,data=aoedata,
              family=binomial)

aoe1=ggplot(aoebinomplot,aes(Red.No,outcome2,color=treatment,
                             group=treatment))+
              geom_point(size=3.5)+
              stat_smooth(method="glm",
                          method.args=list(family="binomial"),
                          se=FALSE)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x="Number of Swordsmen",y="Probability of Victory")+ 
  scale_x_continuous(breaks = seq(0,100,by=20))

aoe1

###Blue Mort####
names(aoedata)
aoebluemort1=glm(cbind(Blue.Mort,Blue.Surv)~treatment*scale(Red.No),data=aoedata,
              family=binomial)
Anova(aoebluemort1)
aoebluemort1
227.3/353.1
#0.64

#McFadden's R2
bluenullmod=glm(cbind(Blue.Mort,Blue.Surv)~1,family="binomial",data=aoedata)
blueR2=1-logLik(aoebluemort1)/logLik(bluenullmod)
blueR2
#0.81
names(aoedata)

#Plot
blue1=ggplot(aoedata,aes(Red.No,Blue.Prop,color=treatment,
             group=treatment))+
  geom_point(size=3.5)+
  geom_smooth(method="glm",
              method.args=list(family="binomial"),
              aes(weight=Blue.No,color=treatment),
              se=TRUE)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x="Number of Swordsmen",y="Knight Fatalities")+ 
  scale_x_continuous(breaks = seq(0,100,by=20))
blue1

###Red Mort####
names(aoedata)
aoeredmort1=glm(cbind(Red.Mort,Red.Surv)~treatment*scale(Red.No),data=aoedata,
                 family=binomial)
Anova(aoeredmort1)
aoeredmort1
801.7/1227
#0.65

#McFadden's R2
rednullmod=glm(cbind(Red.Mort,Red.Surv)~1,family="binomial",data=aoedata)
mcredR2=1-logLik(aoeredmort1)/logLik(rednullmod)
mcredR2
#0.73

#Plot
red1=ggplot(aoedata,aes(Red.No,Red.Prop,color=treatment,
                         group=treatment))+
  geom_point(size=3.5)+
  geom_smooth(method="glm",
              method.args=list(family="binomial"),
              aes(weight=Red.No,color=treatment),
              se=TRUE)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x="Number of Swordsmen",y="Swordsmen Fatalities")+ 
  scale_x_continuous(breaks = seq(0,100,by=20))
red1

###Estimating R for AOE####
raoedata=read.csv("Simulated Battles alpha ratio.csv")
names(raoedata)

raoebinom1=glm(outcome~THS,data=raoedata,
              family=binomial)
Anova(raoebinom1)
raoebinom1

#Find R
findInt <- function(model, value) {
function(x) {
    predict(model, data.frame(THS=x), type="response") - value
  }
}

aoeR=uniroot(findInt(raoebinom1,.5),range(raoedata$THS))$root
aoeR

#McFadden's R2
raoenullmod=glm(Outcome~1,family="binomial",data=raoedata)
raoeR2=1-logLik(raoebinom1)/logLik(raoenullmod)
raoeR2
#1

#Plot
raoebinomplot=glm(outcome~THS,data=raoedata,
               family=binomial)

#tiff version

tiff("Extended Data Figure 1.tiff", units="in", width=3.5, height=3.5, res=300)

ggplot(raoebinomplot,aes(THS,outcome))+
  geom_point(size=3.5,color="#4DB6D0")+
  stat_smooth(method="glm",
              method.args=list(family="binomial"),
              se=FALSE, size=1, colour = "#4DB6D0")+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1.5,colour="white"),
        axis.line.y.right=element_line(size=1.5,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x="Number of Swordsmen",y="Probability of Victory")+ 
  scale_x_continuous(breaks = seq(0,10,by=2))

dev.off()

RAOEplot=ggplot(raoebinomplot,aes(THS,outcome))+
  geom_point(size=3.5,color="blue")+
  stat_smooth(method="glm",
              method.args=list(family="binomial"),
              se=FALSE)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x="Number of THS",y="Prob of Victory")+ 
  scale_x_continuous(breaks = seq(0,10,by=1))

#Combine AOE plots for MS####
library(cowplot)

pdf(file="Figure 2.pdf",width=9,height=9,family="Helvetica")

plot_grid(aoe1,blue1,red1,
          nrow=2,
          ncol=2,
          labels=c('a','b','c'),
          align="hv")

dev.off()

#tiff version of plot

tiff("Figure 1.tiff", units="in", width=7, height=7, res=300)

plot_grid(aoe1,blue1,red1,
          nrow=2,
          ncol=2,
          labels=c('a','b','c'),
          align="hv")

dev.off()

###Estimate theta in AOE####
names(aoedata)
#Overall theta
aoetheta=nls(R~(m0^x-m^x)/(n0^x-n^x),
             data=aoedata,start=list(x=0.1))
aoetheta
#theta=1.001

#Subset for simple
aoedataS=subset(aoedata,Treatment=="S")
aoethetaS=nls(R~(m0^x-m^x)/(n0^x-n^x),
             data=aoedataS,start=list(x=0.1))
aoethetaS
#theta=1.047
summary(aoethetaS)
aoethetaSse=0.02657

#Subset for complex
aoedataC=subset(aoedata,Treatment=="C")
aoethetaC=nls(R~(m0^x-m^x)/(n0^x-n^x),
              data=aoedataC,start=list(x=0.1))
aoethetaC
#theta=0.8657
summary(aoethetaC)
aoethetaCse=0.03711

#Compare theta estimates
#Define model
fo=R~(m0^x-m^x)/(n0^x-n^x)
#Subset for coefficients
s=nls(fo,aoedata,subset=Treatment=="S",
      start=list(x=0.1))
c=nls(fo,aoedata,subset=Treatment=="C",
      start=list(x=0.1))
#Model allowing theta to vary by treatment
AOEsc=nls(R~(m0^x[Treatment]-m^x[Treatment])/(n0^x[Treatment]-n^x[Treatment]),
       data=aoedata,subset=Treatment %in% c("S","C"),
       start=as.data.frame(rbind(coef(s),coef(c))))
#Model with fixed theta
AOEm0=nls(fo,data=aoedata,subset=Treatment %in% c("S","C"),
       start=list(x=0.1))
#Compare
anova(AOEm0,AOEsc)

##################################################################
####################ANT TRIALS####################################
##################################################################
library(tidyverse)
#Analyses####

groupdata=read.csv("Ant Combat Data.csv")
grouptada=as_tibble(groupdata)

groupdata %>%
  group_by(Treatment) %>%
  summarise(n())
35/7

groupdata %>%
  group_by(Lh.No) %>%
  summarise(n())

head(groupdata)
names(groupdata)
class(groupdata$Lh.No)
groupdata$Treatment=as.factor(groupdata$Treatment)
groupdata$Ip.Coloy=as.factor(groupdata$Ip.Coloy)
groupdata$Lh.Colony=as.factor(groupdata$Lh.Colony)
groupdata$Battle.ID=as.factor(groupdata$Battle.ID)
groupdata$LhFact=as.factor(groupdata$Lh.No)

binom1=glmer(cbind(Ip.Mort,Ip.Surv)~Treatment*scale(Lh.No)
             +(1|Ip.Coloy)+(1|Lh.Colony),
             family=binomial,data=groupdata)
binom2=glmer(cbind(Ip.Mort,Ip.Surv)~Treatment*scale(Lh.No)
             +(1|Ip.Coloy),
             family=binomial,data=groupdata)
binom3=glmer(cbind(Ip.Mort,Ip.Surv)~Treatment*scale(Lh.No)
             +(1|Lh.Colony),
             family=binomial,data=groupdata)
anova(binom1,binom2)
anova(binom1,binom3)
#Keep both
Anova(binom1)
overdisp.glmer(binom1)
#Overdispersed at the moment
binom4=glmer(cbind(Ip.Mort,Ip.Surv)~Treatment*scale(Lh.No)
             +(1|Ip.Coloy)+(1|Battle.ID),
             family=binomial,data=groupdata)
interaction.plot(groupdata$Lh.No,groupdata$Treatment,groupdata$Ip.Mort)
#Converges
Anova(binom4)
#Remove interaction
binom5=glmer(cbind(Ip.Mort,Ip.Surv)~Treatment+scale(Lh.No)
             +(1|Ip.Coloy)+(1|Lh.Colony)+(1|Battle.ID),
             family=binomial,data=groupdata)
Anova(binom5)

groupdata %>% group_by(Lh.No, Treatment) %>%
  summarise(n())

#Calculate R2
r2_nakagawa(binom5)
#Power analysis
powerSim(binom5, nsim = 50)
#Try reducing the effect size
fixef(binom5)
changed = binom5
fixef(changed)["TreatmentSimple"] <- 1
powerSim(changed, nsim = 1000)
#Try doing a power curve
newbinom5=glmer(cbind(Ip.Mort,Ip.Surv)~Treatment+Lh.No +
             (1|Ip.Coloy)+(1|Lh.Colony)+(1|Battle.ID),
             family=binomial,data=groupdata)


extmodel <- extend(binom5, within = "Treatment + Lh.No", n = 15)

#Power Curve for interaction####
pcint <- powerCurve(extmodel, within = "Treatment + Lh.No",
                  breaks = 1:15, nsim = 1000)
pcint
n <- c(1:15)
Power <- c(0.111, 0.051, 0.349, 0.503, 0.69, 0.851, 0.858, 0.904, 0.917, 0.924, 0.944,
           0.945, 0.959, 0.968, 0.967)
Lower <- c(0.0922, 0.0382, 0.3194, 0.4615, 0.6603, 0.8274, 0.8348, 0.884, 0.8981, 0.9058,
           0.9279, 0.929, 0.9448, 0.9551, 0.9540)
Upper <- c(0.1321, 0.0665, 0.3795, 0.5344, 0.7186, 0.8725, 0.8791, 0.9215, 0.9334, 0.9397,
           0.9574, 0.9583, 0.9704, 0.978, 0.9772)
powercurvedata <- cbind(n, Power, Lower, Upper)
powercurvedata <- as_tibble(powercurvedata)
powercurvedata

library(ggtext)

#tiff version

tiff("Extended Data Figure 5.tiff", units="in", width=3.5, height=3.5, res=300)

powercurveplot

dev.off()

#Plot####
ant1=ggplot(groupdata,aes(Lh.No,propmort,color=Treatment,
                          group=Treatment))+
  geom_point(size=3.5)+
  geom_smooth(method="glm",
              method.args=list(family="binomial"),
              aes(weight=Lh.No,color=Treatment),
              se=TRUE)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=ggtext::element_markdown(size=rel(1.5)),
        axis.title.x=ggtext::element_markdown(size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x="Number of Argentine Ants",y="Meat Ant Fatalities")+ 
  scale_x_continuous(breaks = seq(0,200,by=50))
ant1


#######REPEAT ALL ANT ANLAYSES BUT REMOVE MEAN NON COMBAT MORTALITY##########
#####
###Baseline Mortality####
base=read.csv("Baseline Mortality.csv")
base <- as_tibble(base)
base

names(base)
head(base)
base$Treatment=as.factor(base$Treatment)

basemort1=glmer(cbind(Mortality,Survival)~Treatment+(1|Ip.Colony),
                data=base,family=binomial)

basemort2=glm(cbind(Mortality,Survival)~Treatment,
              data=base,family=binomial)
anova(basemort1,basemort2)
Anova(basemort1)

overdisp.glmer(basemort1)
#Overdispersed
basemort3 <- glmer(cbind(Mortality,Survival)~Treatment+(1|Ip.Colony)
                   +(1|ID),
                   data=base,family=binomial)
Anova(basemort3)

base %>%
  summarise(mean(Mortality), median(Mortality))

summary(base$Mortality)
basemean=10.13
basemed=10
basese=sd(base$Mortality)/sqrt(length(base$Mortality))
basese

baseS=subset(base,Treatment=="S")
baseC=subset(base,Treatment=="C")
summary(baseS$Mortality)
summary(baseC$Mortality)

#Adjust by probability
groupdata$CombatMort=groupdata$Ip.Mort*0.5
#Round to make whole
groupdata$CombatMort2=ceiling(groupdata$CombatMort)
groupdata$CombatSurv=groupdata$Ip.No-groupdata$CombatMort2
groupdata$CombatSurv
groupdata$CombatProp=groupdata$CombatMort2/(groupdata$CombatMort2+groupdata$CombatSurv)
groupdata$CombatProp

#Models####
cbinom1=glmer(cbind(CombatMort2,CombatSurv)~Treatment*scale(Lh.No)
              +(1|Ip.Coloy)+(1|Lh.Colony),
              family=binomial,data=groupdata)
cbinom2=glmer(cbind(CombatMort2,CombatSurv)~Treatment*scale(Lh.No)
              +(1|Ip.Coloy),
              family=binomial,data=groupdata)
cbinom3=glmer(cbind(CombatMort2,CombatSurv)~Treatment*scale(Lh.No)
              +(1|Lh.Colony),
              family=binomial,data=groupdata)
anova(cbinom1,cbinom2)
anova(cbinom1,cbinom3)
#Keep both
Anova(cbinom1)
overdisp.glmer(cbinom1)
#Not overdispersed
#Remove interaction
cbinom5=glmer(cbind(CombatMort2,CombatSurv)~Treatment+scale(Lh.No)
              +(1|Ip.Coloy)+(1|Lh.Colony),
              family=binomial,data=groupdata)
Anova(cbinom5)
overdisp.glmer(cbinom5)

r2_nakagawa(cbinom5)

#Get sample sizes
base %>%
  group_by(Treatment) %>%
  summarise(n())

#Plot####
combatant1=ggplot(groupdata,aes(Lh.No,CombatProp,color=Treatment,
                                group=Treatment))+
  geom_point(size=3.5)+
  geom_smooth(method="glm",
              method.args=list(family="binomial"),
              aes(weight=Lh.No,color=Treatment),
              se=TRUE)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=ggtext::element_markdown(size=rel(1.5)),
        axis.title.x=ggtext::element_markdown(size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x="Number of Argentine Ants",y="Meat Ant Fatalities")+ 
  scale_x_continuous(breaks = seq(0,200,by=50))
combatant1

###tiff version for MS####

#tiff version

tiff("Extended Data Figure 6.tiff", units="in", width=3.5, height=3.5, res=300)

combatant1

dev.off()

###Theta for ants####

groupdata2=read.csv("Ant Combat Data.csv")
head(groupdata2)
names(groupdata2)
class(groupdata2$Lh.No)
groupdata2$Treatment=as.factor(groupdata2$Treatment)
groupdata2$Ip.Coloy=as.factor(groupdata2$Ip.Coloy)
groupdata2$Lh.Colony=as.factor(groupdata2$Lh.Colony)
groupdata2$Battle.ID=as.factor(groupdata2$Battle.ID)
groupdata2$LhFact=as.factor(groupdata2$Lh.No)


#set the variables that will hold the coef values to NULL initially
boot.intercept<-NULL
boot.scale1<-NULL
boot.treatment<-NULL
boot.scale1bytreatment<-NULL

boot.interceptS<-NULL
boot.scaleS1<-NULL
boot.interceptC<-NULL
boot.scaleC1<-NULL

preds=NULL
predc=NULL
sdpreds=NULL
sdpredc=NULL

predsdata=data.frame(matrix(ncol=10000,nrow=30))
predcdata=data.frame(matrix(ncol=10000,nrow=30))

for (i in 1:10000)  {    #just loop 10 times for now
  
  #Draw 1 values from a random uniform distribution between mean-SE and mean+SE for each R values
  #R=0.01
  s01=runif(n=1,min=0.8953-0.1946,max=0.8953+0.1946)
  #R=0.02
  s02=runif(n=1,min=0.8753-0.1850,max=.8753+0.1850)
  #R=0.03
  s03=runif(n=1,min=0.8558-0.1757,max=0.8558+0.1757)
  #R=0.04
  s04=runif(n=1,min=0.8366-0.1669,max=0.8366+0.1669)
  #R=0.05
  s05=runif(n=1,min=0.8180-0.1585,max=0.8180+0.1585)
  #R=0.06
  s06=runif(n=1,min=0.7997-0.1505,max=0.7997+0.1505)
  #R=0.07
  s07=runif(n=1,min=0.782-0.143,max=0.782+0.143)
  #R=0.08
  s08=runif(n=1,min=0.7649-0.1358,max=0.7649+0.1358)
  #R=0.09
  s09=runif(n=1,min=0.7482-0.1289,max=0.7482+0.1289)
  #R=0.1
  s10=runif(n=1,min=0.7322-0.1225,max=0.7322+0.1225)
  #R=0.11
  s11=runif(n=1,min=0.7167-0.1164,max=0.7167+0.1164)
  #R=0.12
  s12=runif(n=1,min=0.7017-0.1106,max=0.7017+0.1106)
  #R=0.13
  s13=runif(n=1,min=0.6874-0.1052,max=0.6874+0.1052)
  #R=0.14
  s14=runif(n=1,min=0.6736-0.1052,max=0.6736+0.1052)
  #R=0.15
  s15=runif(n=1,min=0.66033-0.09525,max=0.66033+0.09525)
  #R=0.16
  s16=runif(n=1,min=0.64763-0.09077,max=0.64763+0.09077)
  #R=0.17
  s17=runif(n=1,min=0.63546-0.08659,max=0.63546+0.08659)
  #R=0.18
  s18=runif(n=1,min=0.6238-0.08272,max=0.6238+0.08272)
  #R=0.19
  s19=runif(n=1,min=0.61265-0.07916,max=0.61265+0.07916)
  #R=0.2
  s20=runif(n=1,min=0.60197-0.07589,max=0.60197+0.07589)
  #R=0.21
  s21=runif(n=1,min=0.59176-0.07292,max=0.59176+0.07292)
  #R=0.22
  s22=runif(n=1,min=0.58199-0.07025,max=0.58199+0.07025)
  #R=0.23
  s23=runif(n=1,min=0.57265-0.06788,max=0.57265+0.06788)
  #R=0.24
  s24=runif(n=1,min=0.56371-0.06581,max=0.56371+0.06581)
  #R=0.25
  s25=runif(n=1,min=0.55516-0.06404,max=0.55516+0.06404)
  #R=0.26
  s26=runif(n=1,min=0.54697-0.06256,max=0.54697+0.06256)
  #R=0.27
  s27=runif(n=1,min=0.53913-0.06138,max=0.53913+0.06138)
  #R=0.28
  s28=runif(n=1,min=0.53163-0.06048,max=0.53163+0.06048)
  #R=0.29
  s29=runif(n=1,min=0.52444-0.05987,max=0.52444+0.05987)
  #R=0.3
  s30=runif(n=1,min=0.51754-0.05952,max=0.51754+0.05952)
  
  #Did the same thing as above but for the complex treatment
  groupdata2$R=0.1
  antdataC=subset(groupdata2,Treatment=="Complex")
  antthetaC=nls(R~(m0^x-m^x)/(n0^x-n^x),
                data=antdataC,start=list(x=0.01),
                control=nls.control(maxiter=500))
  antthetaC
  summary(antthetaC)
  
  #R=0.01
  c01=runif(n=1,min=0.06575-0.03797,max=0.06575+0.03797)
  #R=0.02
  c02=runif(n=1,min=0.07404-0.03898,max=0.07404+0.03898)
  #R=0.03
  c03=runif(n=1,min=0.08303-0.04016,max=0.08303+0.04016)
  #R=0.04
  c04=runif(n=1,min=0.09289-0.04155,max=0.09289+0.04155)
  #R=0.05
  c05=runif(n=1,min=0.10386-0.04323,max=0.10386+0.04323)
  #R=0.06
  c06=runif(n=1,min=0.11630-0.04529,max=0.11630+0.04529)
  #R=0.07
  c07=runif(n=1,min=0.13085-0.04791,max=0.13085+0.04791)
  #R=0.08
  c08=runif(n=1,min=0.14879-0.05144,max=0.14879+0.05144)
  #R=0.09
  c09=runif(n=1,min=0.17361-0.05685,max=0.17361+0.05685)
  #R=0.1
  c10=runif(n=1,min=0.5033-0.1072,max=0.5033+0.1072)
  #R=0.11
  c11=runif(n=1,min=0.4994-0.1035,max=0.4994+0.1035)
  #R=0.12
  c12=runif(n=1,min=0.496-0.1001,max=0.496+0.1001)
  #R=0.13
  c13=runif(n=1,min=0.4931-0.0969,max=0.4931+0.0969)
  #R=0.14
  c14=runif(n=1,min=0.4906-0.09396,max=0.4906+0.09396)
  #R=0.15
  c15=runif(n=1,min=0.4884-0.0913,max=0.4884+0.0913)
  #R=0.16
  c16=runif(n=1,min=0.48649-0.08892,max=0.48649+0.08892)
  #R=0.17
  c17=runif(n=1,min=0.48479-0.08683,max=0.48479+0.08683)
  #R=0.18
  c18=runif(n=1,min=0.4833-0.08507,max=0.4833+0.08507)
  #R=0.19
  c19=runif(n=1,min=0.48197-0.08364,max=0.48197+0.08364)
  #R=0.2
  c20=runif(n=1,min=0.48078-0.08255,max=0.48078+0.08255)
  #R=0.21
  c21=runif(n=1,min=0.47971-0.08182,max=0.47971+0.08182)
  #R=0.22
  c22=runif(n=1,min=0.47875-0.08145,max=0.47875+0.08145)
  #R=0.23
  c23=runif(n=1,min=0.47788-0.08145,max=0.47788+0.08145)
  #R=0.24
  c24=runif(n=1,min=0.47709-0.08182,max=0.47709+0.08182)
  #R=0.25
  c25=runif(n=1,min=0.47636-0.08254,max=0.47636+0.08254)
  #R=0.26
  c26=runif(n=1,min=0.4757-0.08361,max=0.4757+0.08361)
  #R=0.27
  c27=runif(n=1,min=0.47509-0.08501,max=0.47509+0.08501)
  #R=0.28
  c28=runif(n=1,min=0.47453-0.08673,max=0.47453+0.08673)
  #R=0.29
  c29=runif(n=1,min=0.47401-0.08875,max=0.47401+0.08875)
  #R=0.3
  c30=runif(n=1,min=0.47353-0.09105,max=0.47353+0.09105)
  
  #I made a dataset with all these values of theta, R, and treatment
  #as column headers
  theta=c(s01,s02,s03,s04,s05,s06,s07,s08,s09,s10,s11,s12,s13,s14,s15,
          s16,s17,s18,s19,s20,s21,s22,s23,s24,s25,s26,s27,s28,s29,s30,
          c01,c02,c03,c04,c05,c06,c07,c08,c09,c10,c11,c12,c13,c14,c15,
          c16,c17,c18,c19,c20,c21,c22,c23,c24,c25,c26,c27,c28,c29,c30)
  length(theta)
  treatment=rep(c("s","c"),each=30)
  R=rep(c(0.01,0.02,0.03,0.04,0.05,0.06,0.07,0.08,0.09,0.10,
          0.11,0.12,0.13,0.14,0.15,0.16,0.17,0.18,0.19,0.20,
          0.21,0.22,0.23,0.24,0.25,0.26,0.27,0.28,0.29,0.30,
          0.01,0.02,0.03,0.04,0.05,0.06,0.07,0.08,0.09,0.10,
          0.11,0.12,0.13,0.14,0.15,0.16,0.17,0.18,0.19,0.20,
          0.21,0.22,0.23,0.24,0.25,0.26,0.27,0.28,0.29,0.30),
        each=1)
  thetadat=cbind(theta,treatment,R)
  thetadat=as.data.frame(thetadat)
  thetadat$theta=as.numeric(as.character(thetadat$theta))
  thetadat$theta
  thetadat$R=as.numeric(as.character(thetadat$R))
  thetadat$R
  class(thetadat$treatment)
  head(thetadat)
  
  #Subset again into S and C
  thetadatS=subset(thetadat,treatment=="s")
  thetadatC=subset(thetadat,treatment=="c")
  
  #Analysed theta in terms of R and treatment
  theta1=lm(theta~log(R)*treatment,data=thetadat)
  predict.lm(theta1)
  #Also do models to get just c and s lines
  thetas=lm(theta~log(R),data=thetadatS)
  thetac=lm(theta~log(R),data=thetadatC)
  predict(thetas)
  predict(thetac)
  #Anova(theta1)
  #plot(theta1)
  #shapiro.test(theta1$residuals)
  #opt.expon.mod(theta1)
  #summary(theta1)
  #summary(thetas)
  #summary(thetac)
  
  boot.intercept[i]<-coef(theta1)[1]
  boot.scale1[i]<-coef(theta1)[2]
  boot.treatment[i]<-coef(theta1)[3]
  boot.scale1bytreatment[i]<-coef(theta1)[4]
  boot.scale2bytreatment[i]<-coef(theta1)[5]
  
  #Do the same for the subset models
  boot.interceptS[i]<-coef(thetas)[1]
  boot.scaleS1[i]<-coef(thetas)[2]
  
  boot.interceptC[i]<-coef(thetac)[1]
  boot.scaleC1[i]<-coef(thetac)[2]
  
  predsdata[,i]=predict(thetas)
  predcdata[,i]=predict(thetac)
  
} #end of loop
#after the loop is done, then you could get the mean and SD of the intercepts and slopes

mean(boot.intercept)
sd(boot.intercept)
mean(boot.intercept)-2*sd(boot.intercept)
mean(boot.intercept)+2*sd(boot.intercept)

mean(boot.scale1)
sd(boot.scale1)
mean(boot.scale1)-2*sd(boot.scale1)
mean(boot.scale1)+2*sd(boot.scale1)

mean(boot.treatment)
sd(boot.treatment)
mean(boot.treatment)+2*sd(boot.treatment)
mean(boot.treatment)-2*sd(boot.treatment)

mean(boot.scale1bytreatment)
sd(boot.scale1bytreatment)
mean(boot.scale1bytreatment)-2*sd(boot.scale1bytreatment)
mean(boot.scale1bytreatment)+2*sd(boot.scale1bytreatment)

preddata=rbind(predsdata,predcdata)

predmeans=rowMeans(preddata)
preddatamat=as.matrix(preddata)
predsds=rowSds(preddatamat)

predsds

#you should then be able to use those values to plot the true lines through the data
#####
mean <- c(0.99653007, 0.90641841, 0.85370647, 0.81630675, 0.78729728, 0.76359481, 0.74355466, 0.72619509, 0.71088287, 0.69718561,
          0.68479494, 0.67348315, 0.66307730, 0.65344300, 0.64447367, 0.63608343, 0.62820201, 0.62077120, 0.61374227, 0.60707395,
          0.60073105, 0.59468328, 0.58890439, 0.58337149, 0.57806448, 0.57296564, 0.56805926, 0.56333134, 0.55876934, 0.55436201,
          -0.06903842, 0.05362976, 0.12538605,  0.17629794,  0.21578827,  0.24805423,  0.27533470,  0.29896612,  0.31981051,  0.33845645,
          0.35532376,  0.37072241,  0.38488779,  0.39800288,  0.41021274,  0.42163430,  0.43236321,  0.44247869,  0.45204712,  0.46112463,
          0.46975917,  0.47799194,  0.48585869,  0.49339059,  0.50061497,  0.50755597,  0.51423498,  0.52067106,  0.52688127,  0.53288092)

sd <- c(0.056421596, 0.043088822, 0.035384973, 0.029999252, 0.025898096, 0.022624659, 0.019938807, 0.017700910, 0.015824738, 0.014255200, 0.012956400,
        0.011904313, 0.011081577, 0.010473379, 0.010064247, 0.009836048, 0.009767509, 0.009835149, 0.010015005, 0.010284385, 0.010623113, 0.011014105,
        0.011443413, 0.011899943, 0.012375029, 0.012861985, 0.013355699, 0.013852287, 0.014348817, 0.014843088, 0.016336276, 0.012029640, 0.009855613,
        0.008606130, 0.007892007, 0.007524667, 0.007390069, 0.007411720, 0.007536788, 0.007728906, 0.007963316, 0.008223321, 0.008497730, 0.008779069,
        0.009062367, 0.009344336, 0.009622826, 0.009896457, 0.010164374, 0.010426078, 0.010681317, 0.010930005, 0.011172167, 0.011407906, 0.011637375,
        0.011860756, 0.012078251, 0.012290073, 0.012496436, 0.012697555)


#mean=c(0.7332,0.7167,0.7017,0.6874,0.6736,0.66033,0.64763,0.63546,0.6238,
#       0.61265,0.60197,0.59176,0.58199,0.57265,0.56371,0.55516,0.54697,
#       0.53913,0.53163,0.52444,0.51754,0.5033,0.4994,0.496,0.4931,0.4906,
#       0.4884,0.48649,0.48479,0.4833,0.48197,0.48078,0.47971,0.47875,
#       0.47788,0.47709,0.47636,0.4757,0.47509,0.47453,0.47401,0.47353)
#sd=c(0.1225,0.1164,0.1106,0.1052,0.1052,0.09525,0.09077,0.08659,0.08272,
#     0.07916,0.07589,0.07292,0.07025,0.06788,0.06581,0.06404,0.06256,
#     0.06138,0.06048,0.05987,0.05952,0.1072,0.1035,0.1001,0.0969,0.09396,
#     0.0913,0.08892,0.08683,0.08507,0.08364,0.08255,0.08182,0.08145,
#     0.08145,0.08182,0.08254,0.08361,0.08501,0.08673,0.08875,0.09105)

treatment=rep(c("s","c"),each=30)

R=c(0.01,0.02,0.03,0.04,0.05,0.06,0.07,0.08,0.09,0.10,
    0.11,0.12,0.13,0.14,0.15,0.16,0.17,0.18,0.19,0.20,
    0.21,0.22,0.23,0.24,0.25,0.26,0.27,0.28,0.29,0.30,
    0.01,0.02,0.03,0.04,0.05,0.06,0.07,0.08,0.09,0.10,
    0.11,0.12,0.13,0.14,0.15,0.16,0.17,0.18,0.19,0.20,
    0.21,0.22,0.23,0.24,0.25,0.26,0.27,0.28,0.29,0.30)

ID=c(1:60)

thetadata=cbind(mean,sd,treatment,R,ID,predmeans,predsds)
thetadata=as.data.frame(thetadata)
thetadata$mean=as.numeric(as.character(thetadata$mean))
thetadata$sd=as.numeric(as.character(thetadata$sd))
thetadata$R=as.numeric(as.character(thetadata$R))
thetadata$predmeans=as.numeric(as.character(thetadata$predmeans))
thetadata$predsds=as.numeric(as.character(thetadata$predsds))
thetadata$se = thetadata$predsds/sqrt(10000)

pdf(file="Figure 3.pdf",width=4.5,height=4.5,family="Helvetica")

ggplot(thetadata,aes(R,mean,color=treatment,
                     group=treatment))+
  geom_point(size=3)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x=expression(alpha["Lh"]/alpha["Ip"]),y=expression(theta))+ 
  scale_x_continuous(breaks = seq(0.1,0.3,by=0.05))+
  geom_line(aes(R,predmeans,color=treatment,group=treatment),size=1)+
  geom_line(aes(R,predmeans+predsds,color=treatment,group=treatment),
            linetype="dashed",size=1)+
  geom_line(aes(R,predmeans-predsds,color=treatment,group=treatment),
            linetype="dashed",size=1)

dev.off()

###Now calculate the differential and plot it
mean_S <- mean[1:30]
mean_C <- mean[31:60]  
sd_S <- sd[1:30]  
sd_C <- sd[1:30]  
mean_diff <- mean_S - mean_C
sd_diff <- sqrt((sd_S)^2 + (sd_C)^2)
R_diff <- c(0.01,0.02,0.03,0.04,0.05,0.06,0.07,0.08,0.09,0.10,
            0.11,0.12,0.13,0.14,0.15,0.16,0.17,0.18,0.19,0.20,
            0.21,0.22,0.23,0.24,0.25,0.26,0.27,0.28,0.29,0.30)  
ID_diff <- c(1:30)

diff_data=cbind(mean_diff,sd_diff,ID_diff,R_diff)
diff_data=as.data.frame(diff_data)
diff_data$mean_diff=as.numeric(as.character(diff_data$mean_diff))
diff_data$sd_diff=as.numeric(as.character(diff_data$sd_diff))
diff_data$R_diff=as.numeric(as.character(diff_data$R_diff))
diff_data

ggplot(diff_data,aes(R_diff,mean_diff))+
  geom_point(size=3)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x=expression(alpha["Lh"]/alpha["Ip"]),y=expression(theta["Simple"] - theta["Complex"]))+ 
  scale_x_continuous(breaks = seq(0.1,0.3,by=0.05))+
  geom_line(aes(R_diff,mean_diff),size=1)+
  geom_line(aes(R_diff,mean_diff+sd_diff),
            linetype="dashed",size=1)+
  geom_line(aes(R_diff,mean_diff-sd_diff),
            linetype="dashed",size=1)  

diff_plot <- ggplot(diff_data,aes(R_diff,mean_diff))+
  geom_point(size=2.5)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x=expression(alpha["Lh"]/alpha["Ip"]),y=expression(theta["Simple"] - theta["Complex"]))+ 
  scale_x_continuous(breaks = seq(0.1,0.3,by=0.05))+
  geom_line(aes(R_diff,mean_diff),size=1)+
  geom_line(aes(R_diff,mean_diff+sd_diff),
            linetype="dashed",size=1)+
  geom_line(aes(R_diff,mean_diff-sd_diff),
            linetype="dashed",size=1)  
diff_plot


thetaplot=ggplot(thetadata,aes(R,mean,color=treatment,
                               group=treatment))+
  geom_point(size=2.5)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x=expression(alpha["Lh"]/alpha["Ip"]),y=expression(theta))+ 
  scale_x_continuous(breaks = seq(0,0.3,by=0.05))+
  geom_line(aes(R,predmeans,color=treatment,group=treatment),size=1)+
  geom_line(aes(R,predmeans+predsds,color=treatment,group=treatment),
            linetype="dashed",size=1)+
  geom_line(aes(R,predmeans-predsds,color=treatment,group=treatment),
            linetype="dashed",size=1)

thetaplot

#tiff version

tiff("Figure 3.tiff", units="in", width=3.5, height=3.5, res=300)

ggplot(thetadata,aes(R,mean,color=treatment,
                     group=treatment))+
  geom_point(size=2.5)+
  theme(legend.position="none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(size=1,colour="black"),
        axis.line.y.left=element_line(size=1,colour="black"),
        axis.line.x.top=element_line(size=1,colour="white"),
        axis.line.y.right=element_line(size=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x=expression(alpha["Lh"]/alpha["Ip"]),y=expression(theta))+ 
  scale_x_continuous(breaks = seq(0.1,0.3,by=0.05))+
  geom_line(aes(R,predmeans,color=treatment,group=treatment),size=1)+
  geom_line(aes(R,predmeans+predsds,color=treatment,group=treatment),
            linetype="dashed",size=1)+
  geom_line(aes(R,predmeans-predsds,color=treatment,group=treatment),
            linetype="dashed",size=1)

dev.off()


##COMBINE PLOTS FOR MANUSCRIPT##

library(cowplot)

tiff("Figure 2.tiff", units="in", width=10, height=5, res=300)

plot_grid(ant1,thetaplot,
          nrow=1,
          ncol=2,
          labels=c('a','b'),
          align="hv")

dev.off()

##################################################################
####################CALL MAIN RESULTS#############################
##################################################################
######

#AOE Outcome
Anova(aoebinom2)
aoeR2
aoe1
#AOE Blue Mort
Anova(aoebluemort1)
blueR2
blue1
#AOE Red Mort
Anova(aoeredmort1)
mcredR2
red1
#R for AOE
1/aoeR
raoeR2
RAOEplot
#AOE Theta
summary(aoethetaS)
summary(aoethetaC)
anova(AOEm0,AOEsc)
#Ants Outcome
Anova(binom5)
r2_nakagawa(binom5)
ant1
#Remove Non-Combat Mortality
Anova(cbinom5)
r2_nakagawa(cbinom5)
combatant1
#Ant Theta
thetaplot


##################################################################
###############CLUSTERING IN FILMED TRIALS########################
##################################################################

setwd("C:/Users/samue/OneDrive - Murdoch University/Ant Videos/Data")
setwd("C:/Users/20191200/OneDrive - Murdoch University/Ant Videos/Data")

library(tidyverse)
library(spatstat)
library(car)
library(MuMIn)

###Read in datasets with x and y coordinated of points for each trial
###t1 to t5 are for trials with meat ants present
###t6 to t10 are for trial with meat ants absent
t1 <- read.csv("T1.csv")
t2 <- read.csv("T2.csv")
t3 <- read.csv("T3.csv")
t4 <- read.csv("T4.csv")
t5 <- read.csv("T5.csv")
t6 <- read.csv("T6.csv")
t7 <- read.csv("T7.csv")
t8 <- read.csv("T8.csv")
t9 <- read.csv("T9.csv")
t10 <- read.csv("T10.csv")

###Make point patterns for each snapshot within each trial
###Then combine point patterns into a hyperframe for each trial

####T1####

names(t1)

x1_60 <- as.vector(t1$x60m)
y1_60 <- as.vector(t1$y60m)

points1_60 <- ppp(x1_60, y1_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points1_60
plot(points1_60)
#25 points

x1_120 <- as.vector(t1$x120m)
y1_120 <- as.vector(t1$y120m)

points1_120 <- ppp(x1_120, y1_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points1_120
plot(points1_120)
#25 points


x1_180 <- as.vector(t1$x180m)
y1_180 <- as.vector(t1$y180m)

points1_180 <- ppp(x1_180, y1_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points1_180
plot(points1_180)
#24 points

points1 <- listof(points1_60, points1_120, points1_180)
time1 <- c(time1_60, time1_120, time1_180)
treatment1 <- c(treatment1_60, treatment1_120, treatment1_120)

frame1 <- hyperframe(Points = points1,
                     Time = c(60, 120, 180),
                     Treatment = c("y", "y", "y"),
                     Trial = c("A", "A", "A"))
frame1


####T2####
names(t2)

x2_60 <- as.vector(t2$x60m)
y2_60 <- as.vector(t2$y60m)

points2_60 <- ppp(x2_60, y2_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points2_60
plot(points2_60)
#23 points

x2_120 <- as.vector(t2$x120m)
y2_120 <- as.vector(t2$y120m)

points2_120 <- ppp(x2_120, y2_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points2_120
plot(points2_120)
#25 points

x2_180 <- as.vector(t2$x180m)
y2_180 <- as.vector(t2$y180m)

points2_180 <- ppp(x2_180, y2_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points2_180
plot(points2_180)
#23 points
t2
x2_240 <- as.vector(t2$x240)
y2_240 <- as.vector(t2$y240)

points2_240 <- ppp(x2_240, y2_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points2_240
plot(points2_240)

x2_360 <- as.vector(t2$x360)
y2_360 <- as.vector(t2$y360)

points2_360 <- ppp(x2_360, y2_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points2_360
plot(points2_360)


points2 <- listof(points2_60, points2_120, points2_180,
                  points2_240, points2_360)

frame2 <- hyperframe(Points = points2,
                     Time = c(60, 120, 180, 240, 360),
                     Treatment = c("y", "y", "y", "y", "y"),
                     Trial = c("B", "B", "B", "B", "B"))
frame2



####T3####
names(t3)

x3_60 <- as.vector(t3$x60m)
y3_60 <- as.vector(t3$y60m)

points3_60 <- ppp(x3_60, y3_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points3_60
plot(points3_60)
#14 points

x3_120 <- as.vector(t3$x120m)
y3_120 <- as.vector(t3$y120m)

points3_120 <- ppp(x3_120, y3_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points3_120
plot(points3_120)
#13 points

x3_180 <- as.vector(t3$x180m)
y3_180 <- as.vector(t3$y180m)

points3_180 <- ppp(x3_180, y3_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points3_180
plot(points3_180)
#15 points

x3_240 <- as.vector(t3$x240)
y3_240 <- as.vector(t3$y240)

points3_240 <- ppp(x3_240, y3_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points3_240
plot(points3_240)
#14 points

x3_300 <- as.vector(t3$x300)
y3_300 <- as.vector(t3$y300)

points3_300 <- ppp(x3_300, y3_300, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points3_300
plot(points3_300)
#15 points

x3_360 <- as.vector(t3$x360)
y3_360 <- as.vector(t3$y360)

points3_360 <- ppp(x3_360, y3_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points3_360
plot(points3_360)
#15 points

points3 <- listof(points3_60, points3_120, points3_180,
                  points3_240, points3_300, points3_360)

frame3 <- hyperframe(Points = points3,
                     Time = c(60, 120, 180, 240, 300, 360),
                     Treatment = c("y", "y", "y", "y", "y", "y"),
                     Trial = c("C", "C", "C", "C", "C", "C"))
frame3


####T4####
names(t4)

x4_60 <- as.vector(t4$x60m)
y4_60 <- as.vector(t4$y60m)

points4_60 <- ppp(x4_60, y4_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points4_60
plot(points4_60)
#20 points

x4_120 <- as.vector(t4$x120m)
y4_120 <- as.vector(t4$y120m)

points4_120 <- ppp(x4_120, y4_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points4_120
plot(points4_120)
#20 points

x4_180 <- as.vector(t4$x180m)
y4_180 <- as.vector(t4$y180m)

points4_180 <- ppp(x4_180, y4_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points4_180
plot(points4_180)
#20 points

x4_240 <- as.vector(t4$x240)
y4_240 <- as.vector(t4$y240)

points4_240 <- ppp(x4_240, y4_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points4_240
plot(points4_240)
#20 points

x4_300 <- as.vector(t4$x300)
y4_300 <- as.vector(t4$y300)

points4_300 <- ppp(x4_300, y4_300, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points4_300
plot(points4_300)
#20 points

x4_360 <- as.vector(t4$x360)
y4_360 <- as.vector(t4$y360)

points4_360 <- ppp(x4_360, y4_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points4_360
plot(points4_360)
#20 points

points4 <- listof(points4_60, points4_120, points4_180,
                  points4_240, points4_300, points4_360)

frame4 <- hyperframe(Points = points4,
                     Time = c(60, 120, 180, 240, 300, 360),
                     Treatment = c("y", "y", "y", "y", "y", "y"),
                     Trial = c("D", "D", "D", "D", "D", "D"))
frame4
plot(frame4)


####T5####
names(t5)

x5_60 <- as.vector(t5$x60m)
y5_60 <- as.vector(t5$y60m)

points5_60 <- ppp(x5_60, y5_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points5_60
plot(points5_60)
#16 points

x5_120 <- as.vector(t5$x120m)
y5_120 <- as.vector(t5$y120m)

points5_120 <- ppp(x5_120, y5_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points5_120
plot(points5_120)
#15 points

x5_180 <- as.vector(t5$x180m)
y5_180 <- as.vector(t5$y180m)

points5_180 <- ppp(x5_180, y5_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points5_180
plot(points5_180)
#15 points

x5_240 <- as.vector(t5$x240)
y5_240 <- as.vector(t5$y240)

points5_240 <- ppp(x5_240, y5_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points5_240
plot(points5_240)
#15 points

x5_300 <- as.vector(t5$x300)
y5_300 <- as.vector(t5$y300)

points5_300 <- ppp(x5_300, y5_300, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points5_300
plot(points5_300)
#15 points

x5_360 <- as.vector(t5$x360)
y5_360 <- as.vector(t5$y360)

points5_360 <- ppp(x5_360, y5_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points5_360
plot(points5_360)
#15 points

points5 <- listof(points5_60, points5_120, points5_180,
                  points5_240, points5_300, points5_360)

frame5 <- hyperframe(Points = points5,
                     Time = c(60, 120, 180, 240, 300, 360),
                     Treatment = c("y", "y", "y", "y", "y", "y"),
                     Trial = c("E", "E", "E", "E", "E", "E"))
frame5


####T6####
names(t6)

x6_60 <- as.vector(t6$x60m)
y6_60 <- as.vector(t6$y60m)

points6_60 <- ppp(x6_60, y6_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points6_60
plot(points6_60)
#16 points

x6_120 <- as.vector(t6$x120m)
y6_120 <- as.vector(t6$y120m)

points6_120 <- ppp(x6_120, y6_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points6_120
plot(points6_120)
#17 points

x6_180 <- as.vector(t6$x180m)
y6_180 <- as.vector(t6$y180m)

points6_180 <- ppp(x6_180, y6_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points6_180
plot(points6_180)
#14 points

x6_240 <- as.vector(t6$x240)
y6_240 <- as.vector(t6$y240)

points6_240 <- ppp(x6_240, y6_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points6_240
plot(points6_240)
#19 points

x6_360 <- as.vector(t6$x360)
y6_360 <- as.vector(t6$y360)

points6_360 <- ppp(x6_360, y6_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points6_360
plot(points6_360)
#18 points

points6 <- listof(points6_60, points6_120, points6_180,
                  points6_240, points6_360)

frame6 <- hyperframe(Points = points6,
                     Time = c(60, 120, 180, 240, 360),
                     Treatment = c("n", "n", "n", "n", "n"),
                     Trial = "F", "F", "F", "F", "F", "F")
frame6 <- hyperframe(Points = frame6$Points,
                     Time = frame6$Time,
                     Treatment = frame6$Treatment,
                     Trial = frame6$Trial)
frame6

####T7####
names(t7)

x7_60 <- as.vector(t7$x60m)
y7_60 <- as.vector(t7$y60m)

points7_60 <- ppp(x7_60, y7_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points7_60
plot(points7_60)
#17 points

x7_120 <- as.vector(t7$x120m)
y7_120 <- as.vector(t7$y120m)

points7_120 <- ppp(x7_120, y7_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points7_120
plot(points7_120)
#15 points

x7_180 <- as.vector(t7$x180m)
y7_180 <- as.vector(t7$y180m)

points7_180 <- ppp(x7_180, y7_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points7_180
plot(points7_180)
#16 points

x7_240 <- as.vector(t7$x240)
y7_240 <- as.vector(t7$y240)

points7_240 <- ppp(x7_240, y7_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points7_240
plot(points7_240)
#16 points

x7_300 <- as.vector(t7$x300)
y7_300 <- as.vector(t7$y300)

points7_300 <- ppp(x7_300, y7_300, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points7_300
plot(points7_300)
#19 points

x7_360 <- as.vector(t7$x360)
y7_360 <- as.vector(t7$y360)

points7_360 <- ppp(x7_360, y7_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points7_360
plot(points7_360)
#16 points

points7 <- listof(points7_60, points7_120, points7_180,
                  points7_240, points7_300, points7_360)

frame7 <- hyperframe(Points = points7,
                     Time = c(60, 120, 180, 240, 300, 360),
                     Treatment = c("n", "n", "n", "n", "n", "n"),
                     Trial = c("G", "G", "G", "G", "G", "G"))
frame7






####T8####
names(t8)

x8_60 <- as.vector(t8$x60m)
y8_60 <- as.vector(t8$y60m)

points8_60 <- ppp(x8_60, y8_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points8_60
plot(points8_60)
#20 points

x8_120 <- as.vector(t8$x120m)
y8_120 <- as.vector(t8$y120m)

points8_120 <- ppp(x8_120, y8_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points8_120
plot(points8_120)
#20 points

x8_180 <- as.vector(t8$x180m)
y8_180 <- as.vector(t8$y180m)

points8_180 <- ppp(x8_180, y8_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points8_180
plot(points8_180)
#20 points

x8_240 <- as.vector(t8$x240)
y8_240 <- as.vector(t8$y240)

points8_240 <- ppp(x8_240, y8_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points8_240
plot(points8_240)
#20 points

x8_300 <- as.vector(t8$x300)
y8_300 <- as.vector(t8$y300)

points8_300 <- ppp(x8_300, y8_300, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points8_300
plot(points8_300)
#20 points

x8_360 <- as.vector(t8$x360)
y8_360 <- as.vector(t8$y360)

points8_360 <- ppp(x8_360, y8_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points8_360
plot(points8_360)
#20 points

points8 <- listof(points8_60, points8_120, points8_180,
                  points8_240, points8_300, points8_360)

frame8 <- hyperframe(Points = points8,
                     Time = c(60, 120, 180, 240, 300, 360),
                     Treatment = c("n", "n", "n", "n", "n", "n"),
                     Trial = c("H", "H", "H", "H", "H", "H"))
frame8


####T9####
names(t9)

x9_60 <- as.vector(t9$x60m)
y9_60 <- as.vector(t9$y60m)

points9_60 <- ppp(x9_60, y9_60, 
                  window = owin(c(0, 150), c(0, 125)),
                  unitname = "mm")
points9_60
plot(points9_60)
#17 points

x9_120 <- as.vector(t9$x120m)
y9_120 <- as.vector(t9$y120m)

points9_120 <- ppp(x9_120, y9_120, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points9_120
plot(points9_120)
#17 points

x9_180 <- as.vector(t9$x180m)
y9_180 <- as.vector(t9$y180m)

points9_180 <- ppp(x9_180, y9_180, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points9_180
plot(points9_180)
#17 points

x9_240 <- as.vector(t9$x240)
y9_240 <- as.vector(t9$y240)

points9_240 <- ppp(x9_240, y9_240, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points9_240
plot(points9_240)
#17 points

x9_300 <- as.vector(t9$x300)
y9_300 <- as.vector(t9$y300)

points9_300 <- ppp(x9_300, y9_300, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points9_300
plot(points9_300)
#17 points

x9_360 <- as.vector(t9$x360)
y9_360 <- as.vector(t9$y360)

points9_360 <- ppp(x9_360, y9_360, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points9_360
plot(points9_360)
#17 points

points9 <- listof(points9_60, points9_120, points9_180,
                  points9_240, points9_300, points9_360)

frame9 <- hyperframe(Points = points9,
                     Time = c(60, 120, 180, 240, 300, 360),
                     Treatment = c("n", "n", "n", "n", "n", "n"),
                     Trial = c("I", "I", "I", "I", "I", "I"))
frame9


####T10####
names(t10)

x10_60 <- as.vector(t10$x60m)
y10_60 <- as.vector(t10$y60m)

points10_60 <- ppp(x10_60, y10_60, 
                   window = owin(c(0, 150), c(0, 125)),
                   unitname = "mm")
points10_60
plot(points10_60)
#20 points

x10_120 <- as.vector(t10$x120m)
y10_120 <- as.vector(t10$y120m)

points10_120 <- ppp(x10_120, y10_120, 
                    window = owin(c(0, 150), c(0, 125)),
                    unitname = "mm")
points10_120
plot(points10_120)
#20 points

x10_180 <- as.vector(t10$x180m)
y10_180 <- as.vector(t10$y180m)

points10_180 <- ppp(x10_180, y10_180, 
                    window = owin(c(0, 150), c(0, 125)),
                    unitname = "mm")
points10_180
plot(points10_180)
#20 points

x10_240 <- as.vector(t10$x240)
y10_240 <- as.vector(t10$y240)

points10_240 <- ppp(x10_240, y10_240, 
                    window = owin(c(0, 150), c(0, 125)),
                    unitname = "mm")
points10_240
plot(points10_240)
#20 points

x10_300 <- as.vector(t10$x300)
y10_300 <- as.vector(t10$y300)

points10_300 <- ppp(x10_300, y10_300, 
                    window = owin(c(0, 150), c(0, 125)),
                    unitname = "mm")
points10_300
plot(points10_300)
#20 points

x10_360 <- as.vector(t10$x360)
y10_360 <- as.vector(t10$y360)

points10_360 <- ppp(x10_360, y10_360, 
                    window = owin(c(0, 150), c(0, 125)),
                    unitname = "mm")
points10_360
plot(points10_360)
#20 points

points10 <- listof(points10_60, points10_120, points10_180,
                   points10_240, points10_300, points10_360)

frame10 <- hyperframe(Points = points10,
                      Time = c(60, 120, 180, 240, 300, 360),
                      Treatment = c("n", "n", "n", "n", "n", "n"),
                      Trial = c("J", "J", "J", "J", "J", "J"))
frame10

####Group all hyperframes####

frame_all <- rbind(frame1, frame2, frame3, frame4, frame5,
                   frame6, frame7, frame8, frame9, frame10)
frame_all
frame_all$Treatment = as.factor(frame_all$Treatment)
frame_all$Trial = as.factor(frame_all$Trial)
levels(frame_all$Treatment)
levels(frame_all$Trial)

#Run a mixed point process model and examine residuals
cluster_mod1 <- mppm(Points ~ Time * Treatment,
                     random = ~1|Trial,
                     data = frame_all)
cluster_mod1
with(frame_all, ppm(Points))
residuals1 <- residuals(cluster_mod1)
plot(residuals1)

#significance test
anova.mppm(cluster_mod1,
           test = "Chisq")

#Remove interaction
cluster_mod2 <- mppm(Points ~ Time + Treatment,
                     random = ~1|Trial,
                     data = frame_all)

#Significance test
anova.mppm(cluster_mod2,
           test = "Chisq")

#Test if overall pattern differs to random Poisson
cluster_mod3 <- mppm(Points ~ 1,
                     random = ~1|Trial,
                     data = frame_all)
anova.mppm(cluster_mod3)

plot(cluster_mod1$residuals)

#Clustering across all differs to random Poisson
#But not significantly over time or in the presence of 
#meat ants compared to absence

#Pool K functions and plot to examine pattern
K <- lapply(frame_all$Points, Kest, correction="iso")

plot(K)

K[[1]]$r
K[[2]]$r

K$r

Kall <- pool(K[[1]], K[[2]], K[[3]], K[[4]], K[[5]],
             K[[6]], K[[7]], K[[8]], K[[9]], K[[10]],
             K[[11]], K[[12]], K[[13]], K[[14]], K[[15]],
             K[[16]], K[[17]], K[[18]], K[[19]], K[[20]],
             K[[21]], K[[22]], K[[23]], K[[24]], K[[25]],
             K[[26]], K[[27]], K[[28]], K[[29]], K[[30]],
             K[[31]], K[[32]], K[[33]], K[[34]], K[[35]],
             K[[36]], K[[37]], K[[38]], K[[39]], K[[40]],
             K[[41]], K[[42]], K[[43]], K[[44]], K[[45]],
             K[[46]], K[[47]], K[[48]], K[[49]], K[[50]],
             K[[51]], K[[52]], K[[53]], K[[54]], K[[55]])


Kall <- pool(as.anylist(K))
Kall$loiso
Kall$pooltheo

K_all_iso <- Kall$pooliso
K_all_low <- Kall$loiso
K_all_hi <- Kall$hiiso
K_all_theo <- Kall$pooltheo
K_all_treatment <- rep("pooled", each = 513)
r_all <- Kall$r
K_low_theo = Kall$lotheo
K_hi_theo = Kall$hitheo

plot(Kall, cbind(pooliso, pooltheo) ~ r,
     shade=c("loiso", "hiiso"),
     main="Pooled K function of Argentine ants")

#Repeat the above process separately for each treatment
#First for meat ants present
frame_y <- rbind(frame1, frame2, frame3, frame4, frame5)
frame_y$Treatment = as.factor(frame_y$Treatment)
frame_y$Trial = as.factor(frame_y$Trial)

K_y <- lapply(frame_y$Points, Kest, correction="iso")

Kall_y <- pool(as.anylist(K_y))

#Extract the values for plotting later
K_y_iso <- Kall_y$pooliso
K_y_low <- Kall_y$loiso
K_y_hi <- Kall_y$hiiso
K_y_theo <- Kall_y$pooltheo
K_y_treatment <- rep("yes", each = 513)
K_low_theo_y = Kall_y$lotheo
K_hi_theo_y = Kall_y$hitheo

#Now do this for meat ants absent
frame_n <- rbind(frame6, frame7, frame8, frame9, frame10)
frame_n$Treatment = as.factor(frame_n$Treatment)
frame_n$Trial = as.factor(frame_n$Trial)

K_n <- lapply(frame_n$Points, Kest, correction="iso")

Kall_n <- pool(as.anylist(K_n))

#Extract the values
K_n_iso <- Kall_n$pooliso
K_n_low <- Kall_n$loiso
K_n_hi <- Kall_n$hiiso
K_n_theo <- Kall_n$pooltheo
K_n_treatment <- rep("no", each = 513)
k_n_r <- Kall_n$r
K_low_theo_n = Kall_n$lotheo
K_hi_theo_n = Kall_n$hitheo

#Now combine the extracted values into a dataset to make K plot

K_iso <- c(K_y_iso, K_n_iso)
K_low <- c(K_y_low, K_n_low)
K_hi <- c(K_y_hi, K_n_hi)
K_theo <- c(K_y_theo, K_n_theo)
K_treatment <- c(K_y_treatment, K_n_treatment)
r <- rep(r_all, time = 2)

K_data <- cbind(K_iso, K_low, K_hi, K_theo, K_treatment, r)
K_data <- as.data.frame(K_data)
K_data <- as_tibble(K_data)

K_data <- K_data %>%
  mutate(K_iso = as.numeric(K_iso)) %>%
  mutate(K_low = as.numeric(K_low)) %>%
  mutate(K_hi = as.numeric(K_hi)) %>%
  mutate(K_theo = as.numeric(K_theo)) %>%
  mutate(r = as.numeric(r))
K_data

#Construct the plot

k_plot <- ggplot(data = K_data) +
  geom_line(aes(y = K_iso, x = r,
                group = K_treatment, colour = K_treatment)) +
  geom_ribbon(aes(ymin = K_low, ymax = K_hi, x = r,
                  group = K_treatment, colour = K_treatment,
                  fill = K_treatment),
              linetype=2, alpha=0.1) +
  geom_line(aes(y = K_theo, x = r)) +
  theme(legend.position = "none",
        legend.text=element_text(size=rel(1.5)),
        legend.title=element_text(size=rel(1.5),colour="white"),
        panel.background=element_rect(fill="white"),
        axis.line.x.bottom=element_line(linewidth=1,colour="black"),
        axis.line.y.left=element_line(linewidth=1,colour="black"),
        axis.line.x.top=element_line(linewidth=1,colour="white"),
        axis.line.y.right=element_line(linewidth=1,colour="white"),
        axis.ticks.length=unit(.25,"cm"),
        panel.border=element_blank(),
        axis.title.y=element_text(family="sans",size=rel(1.5),angle=90),
        axis.title.x=element_text(family="sans",size=rel(1.5)),
        axis.text=element_text(family="sans",size=rel(1.5),colour="black"))+
  labs(x=expression(italic("r")),y=expression(italic("K(r)")))

#Save for manuscript

tiff("Figure S3.tiff", units="in", width=3.5, height=3.5, res=300)

k_plot

dev.off()



